@@ -813,6 +813,7 @@ sign_in_identity (GoaKerberosIdentityManager *self,
   GoaIdentity *identity;
   GError *error;
   krb5_error_code error_code;
+  gboolean is_new_identity = FALSE;
 
   g_debug ("GoaKerberosIdentityManager: signing in identity %s",
            operation->identifier);
@@ -845,25 +846,23 @@ sign_in_identity (GoaKerberosIdentityManager *self,
       identity = goa_kerberos_identity_new (self->priv->kerberos_context,
                                             credentials_cache,
                                             &error);
-      krb5_cc_close (self->priv->kerberos_context, credentials_cache);
       if (identity == NULL)
         {
+          krb5_cc_destroy (self->priv->kerberos_context, credentials_cache);
           g_simple_async_result_take_error (operation->result, error);
           g_simple_async_result_set_op_res_gpointer (operation->result,
                                                      NULL,
                                                      NULL);
           return;
         }
+      krb5_cc_close (self->priv->kerberos_context, credentials_cache);
+      is_new_identity = TRUE;
     }
   else
     {
       g_object_ref (identity);
     }
 
-  g_hash_table_replace (self->priv->identities,
-                        g_strdup (operation->identifier),
-                        g_object_ref (identity));
-
   if (!goa_kerberos_identity_sign_in (GOA_KERBEROS_IDENTITY (identity),
                                       operation->identifier,
                                       operation->initial_password,
@@ -876,6 +875,9 @@ sign_in_identity (GoaKerberosIdentityManager *self,
                                       operation->cancellable,
                                       &error))
     {
+      if (is_new_identity)
+        goa_kerberos_identity_erase (GOA_KERBEROS_IDENTITY (identity), NULL);
+
       g_simple_async_result_set_from_error (operation->result, error);
       g_simple_async_result_set_op_res_gpointer (operation->result,
                                                  NULL,
@@ -888,6 +890,10 @@ sign_in_identity (GoaKerberosIdentityManager *self,
                                                  g_object_ref (identity),
                                                  (GDestroyNotify)
                                                  g_object_unref);
+
+      g_hash_table_replace (self->priv->identities,
+                            g_strdup (operation->identifier),
+                            g_object_ref (identity));
     }
 
   g_object_unref (identity);
